==> aria2rpc-0.1.0.tar.gz: aria2rpc-0.1.0/README.md <==
# Aria2RPC

<badges>[![version](https://img.shields.io/pypi/v/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)
[![license](https://img.shields.io/pypi/l/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)
[![pyversions](https://img.shields.io/pypi/pyversions/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)  
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![powered](https://img.shields.io/badge/Powered%20by-UTF8-red.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>Simple aria2 XML-RPC client.</i>

# Hierarchy

```
aria2rpc
|---- aria2_rpc_api()
|   |---- addUri()
|   |---- addTorrent()
|   |---- addMetalink()
|   |---- remove()
|   |---- forceRemove()
|   |---- pause()
|   |---- pauseAll()
|   |---- forcePause()
|   |---- forcePauseAll()
|   |---- unpause()
|   |---- unpauseAll()
|   |---- tellStatus()
|   |---- getUris()
|   |---- getFiles()
|   |---- getPeers()
|   |---- getServers()
|   |---- tellActive()
|   |---- tellWaiting()
|   |---- tellStopped()
|   |---- changePosition()
|   |---- changeUri()
|   |---- getOption()
|   |---- changeOption()
|   |---- getGlobalOption()
|   |---- changeGlobalOption()
|   |---- getGlobalStat()
|   |---- purgeDownloadResult()
|   |---- removeDownloadResult()
|   |---- getVersion()
|   |---- getSessionInfo()
|   |---- shutdown()
|   |---- forceShutdown()
|   '---- saveSession()
|---- system_rpc_api()
|   |---- multicall()
|   |---- listMethods()
|   '---- listNotifications()
'---- utils
    '---- generate_core()
```

# Example

## python
See `test`.

==> aria2rpc-1.0.0.tar.gz: aria2rpc-1.0.0/README.md <==
# Aria2RPC

<badges>[![version](https://img.shields.io/pypi/v/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)
[![license](https://img.shields.io/pypi/l/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)
[![pyversions](https://img.shields.io/pypi/pyversions/aria2rpc.svg)](https://pypi.org/project/aria2rpc/)  
[![powered](https://img.shields.io/badge/Say-Thanks-ddddff.svg)](https://saythanks.io/to/foxe6)
[![donate](https://img.shields.io/badge/Donate-Paypal-0070ba.svg)](https://paypal.me/foxe6)
[![made](https://img.shields.io/badge/Made%20with-PyCharm-red.svg)](https://paypal.me/foxe6)
</badges>

<i>Simple aria2 XML-RPC client.</i>

# Hierarchy

```
aria2rpc
|---- aria2_rpc_api()
|   |---- addUri()
|   |---- addTorrent()
|   |---- addMetalink()
|   |---- remove()
|   |---- forceRemove()
|   |---- pause()
|   |---- pauseAll()
|   |---- forcePause()
|   |---- forcePauseAll()
|   |---- unpause()
|   |---- unpauseAll()
|   |---- tellStatus()
|   |---- getUris()
|   |---- getFiles()
|   |---- getPeers()
|   |---- getServers()
|   |---- tellActive()
|   |---- tellWaiting()
|   |---- tellStopped()
|   |---- changePosition()
|   |---- changeUri()
|   |---- getOption()
|   |---- changeOption()
|   |---- getGlobalOption()
|   |---- changeGlobalOption()
|   |---- getGlobalStat()
|   |---- purgeDownloadResult()
|   |---- removeDownloadResult()
|   |---- getVersion()
|   |---- getSessionInfo()
|   |---- shutdown()
|   |---- forceShutdown()
|   '---- saveSession()
|---- system_rpc_api()
|   |---- multicall()
|   |---- listMethods()
|   '---- listNotifications()
'---- utils
    '---- generate_core()
```

# Example

## python
See `test`.
